-
Blog Posts.
+
Journal.
- Here you can find a list of all the blog posts I have written. Some of them are about my
+ Here you can find my journal where I write all kinds of tech-related things. Some of them are about my
projects, some are about my thoughts, and some are about my experiences. I hope you enjoy!
diff --git a/src/routes/blog/[title]/+page.svelte b/src/routes/journal/[title]/+page.svelte
similarity index 88%
rename from src/routes/blog/[title]/+page.svelte
rename to src/routes/journal/[title]/+page.svelte
index 1764378..18a00a9 100644
--- a/src/routes/blog/[title]/+page.svelte
+++ b/src/routes/journal/[title]/+page.svelte
@@ -7,7 +7,7 @@
{#if data.post.error}
+
{@html data.post.content}
{/if}
diff --git a/src/routes/blog/[title]/+page.server.ts b/src/routes/journal/[title]/+page.server.ts
similarity index 91%
rename from src/routes/blog/[title]/+page.server.ts
rename to src/routes/journal/[title]/+page.server.ts
index 701adde..b1c5135 100644
--- a/src/routes/blog/[title]/+page.server.ts
+++ b/src/routes/journal/[title]/+page.server.ts
@@ -8,14 +8,14 @@ import hljs from 'highlight.js';
const cwd = process.cwd();
/**
* Load the blog post from the file system when the page is requested.
* @param {RequestEvent} event
*/
export const load = async ({ url }: RequestEvent) => {
// Create the path
// ./src/[url].md
- const blogPath = cwd.concat("/src", url.pathname, ".md");
- const cleanPath = blogPath.replaceAll("%20", " ");
+ const journalPath = cwd.concat("/src", url.pathname, ".md");
+ const cleanPath = journalPath.replaceAll("%20", " ");
// Read the file and get the data
let content: string = "";
@@ -8,14 +8,14 @@ import hljs from 'highlight.js';
const cwd = process.cwd();
/**
- * Load the blog post from the file system when the page is requested.
+ * Load the journal post from the file system when the page is requested.
* @param {RequestEvent} event
*/